@@ -20,17 +20,14 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 """
 
 from collections import OrderedDict as OD
-from dataclasses import dataclass
 
 import django.template.defaultfilters
 from django.db.models import AutoField, Model, TextField
 from django.test import TestCase
-import yaml
 
 from yamldoc.models import Document, MarkupField
-from yamldoc.util.file import transform
 from yamldoc.util.markup import Inline
-from yamldoc.util.misc import slugify, field_order_fn, unique_alphabetizer
+from yamldoc.util.misc import field_order_fn, slugify, unique_alphabetizer
 from yamldoc.util.placeholder import lacuna
 from yamldoc.util.placeholder import map as placemap
 from yamldoc.util.resolution import combo, map_resolver, markdown_on_string
@@ -38,6 +35,8 @@ from yamldoc.util.traverse import classbased_selector, get_explicit_fields
 
 
 class ConcreteDocument(Document):
+    """A test-only implementation."""
+
     id = AutoField(primary_key=True)
 
 
@@ -47,23 +46,25 @@ class _UpstreamCharacterization(TestCase):
     def test_meta_string(self):
         # Check that Django disallows a novel metadata property.
         with self.assertRaises(TypeError):
+
             class M(Model):
                 id = AutoField(primary_key=True)
                 field = TextField()
 
                 class Meta():
-                    fields_with_markup = ('field',)
+                    fields_with_markup = ('field', )
 
     def test_meta_field(self):
         # Like test_meta_string but with a Field instance.
         textfield = TextField()
         with self.assertRaises(TypeError):
+
             class M(Model):
                 id = AutoField(primary_key=True)
                 field = textfield
 
                 class Meta():
-                    fields_with_markup = (textfield,)
+                    fields_with_markup = (textfield, )
 
     def test_composition_equality(self):
         # Adding a non-metadata non-field member to a model should work.
@@ -71,15 +72,14 @@ class _UpstreamCharacterization(TestCase):
             id = AutoField(primary_key=True)
             field = TextField()
 
-            fields_with_markup = (field,)
+            fields_with_markup = (field, )
 
         # Django is expected to wrap M.field, so that it is not equivalent to
         # field.
-        self.assertNotEqual(M.fields_with_markup, (M.field,))
+        self.assertNotEqual(M.fields_with_markup, (M.field, ))
 
         # Penetrating Django’s DeferredAttribute wrapper should fix that.
-        self.assertEqual([f for f in M.fields_with_markup],
-                         [M.field.field])
+        self.assertEqual([f for f in M.fields_with_markup], [M.field.field])
         self.assertEqual([f.name for f in M.fields_with_markup],
                          [M.field.field.name])
 
@@ -157,6 +157,7 @@ class _CookingMarkdown(TestCase):
 class _CookingInternalMarkup(TestCase):
 
     def test_multiline(self):
+
         def mask(s):
             return s
 
@@ -173,7 +174,11 @@ class _CookingInternalMarkup(TestCase):
 
 class _StructuralTransformation(TestCase):
 
-    def _check_roundtrip(self, fof, input_, oracle, contents_affected=False,
+    def _check_roundtrip(self,
+                         fof,
+                         input_,
+                         oracle,
+                         contents_affected=False,
                          change=True):
         if not contents_affected:
             # When order is disregarded, input_ matches oracle.
@@ -191,92 +196,88 @@ class _StructuralTransformation(TestCase):
         self.assertEqual(OD(ret), OD(oracle))
 
     def test_nokeys(self):
-        self._check_roundtrip(field_order_fn(()),
-                              {'a': 1, 'b': 1}, {'a': 1, 'b': 1},
+        self._check_roundtrip(field_order_fn(()), {
+            'a': 1,
+            'b': 1
+        }, {
+            'a': 1,
+            'b': 1
+        },
                               change=False)
 
     def test_onekey(self):
-        self._check_roundtrip(field_order_fn(('b',)),
-                              {'a': 1, 'b': 1}, {'b': 1, 'a': 1})
-        self._check_roundtrip(field_order_fn(('a',)),
-                              {'a': 1, 'b': 1}, {'a': 1, 'b': 1},
+        self._check_roundtrip(field_order_fn(('b', )), {
+            'a': 1,
+            'b': 1
+        }, {
+            'b': 1,
+            'a': 1
+        })
+        self._check_roundtrip(field_order_fn(('a', )), {
+            'a': 1,
+            'b': 1
+        }, {
+            'a': 1,
+            'b': 1
+        },
                               change=False)
 
     def test_twokey(self):
-        self._check_roundtrip(field_order_fn(('b', 'c')),
-                              {'a': 1, 'b': 1, 'c': 1},
-                              {'b': 1, 'c': 1, 'a': 1})
-        self._check_roundtrip(field_order_fn(('b', 'c')),
-                              {'a': 1, 'b': 1, 'c': 1, 'd': 1},
-                              {'b': 1, 'c': 1, 'a': 1, 'd': 1})
+        self._check_roundtrip(field_order_fn(('b', 'c')), {
+            'a': 1,
+            'b': 1,
+            'c': 1
+        }, {
+            'b': 1,
+            'c': 1,
+            'a': 1
+        })
+        self._check_roundtrip(field_order_fn(('b', 'c')), {
+            'a': 1,
+            'b': 1,
+            'c': 1,
+            'd': 1
+        }, {
+            'b': 1,
+            'c': 1,
+            'a': 1,
+            'd': 1
+        })
 
         # Unreferenced keys go last, with their internal order intact.
-        self._check_roundtrip(field_order_fn(('b', 'c')),
-                              {'c': 1, 'd': 1, 'b': 1, 'a': 1},
-                              {'b': 1, 'c': 1, 'd': 1, 'a': 1})
+        self._check_roundtrip(field_order_fn(('b', 'c')), {
+            'c': 1,
+            'd': 1,
+            'b': 1,
+            'a': 1
+        }, {
+            'b': 1,
+            'c': 1,
+            'd': 1,
+            'a': 1
+        })
 
     def test_composite(self):
-        f0 = field_order_fn(('x',))
+        f0 = field_order_fn(('x', ))
         f1 = unique_alphabetizer('z')
 
         def f(coll):
             return f1(f0(coll))
 
-        self._check_roundtrip(f,
-                              {'a': 1, 'z': [2, 1], 'x': [2, 1]},
-                              {'x': [2, 1], 'a': 1, 'z': [1, 2]},
+        self._check_roundtrip(f, {
+            'a': 1,
+            'z': [2, 1],
+            'x': [2, 1]
+        }, {
+            'x': [2, 1],
+            'a': 1,
+            'z': [1, 2]
+        },
                               contents_affected=True)
 
 
-class _LegacyStructuralTransformation(TestCase):
-
-    class _PseudoModel():
-        class _meta():
-            @dataclass
-            class _PseudoField():
-                name: str
-            fields = (_PseudoField('a'),
-                      _PseudoField('c'),
-                      _PseudoField('b'))
-
-    def _check_str_roundtrip(self, input_, oracle):
-        # When order is disregarded, input_ matches oracle.
-        self.assertEqual(yaml.safe_load(input_),
-                         yaml.safe_load(oracle))
-
-        # When order is regarded, input_ does not match oracle.
-        self.assertNotEqual(input_, oracle)
-        self.assertNotEqual(OD(yaml.safe_load(input_)),
-                            OD(yaml.safe_load(oracle)))
-
-        # Perform operation.
-        ret = transform(self._PseudoModel, input_)
-
-        # Order is established.
-        self.assertEqual(ret, oracle)
-        self.assertEqual(OD(yaml.safe_load(ret)),
-                         OD(yaml.safe_load(oracle)))
-
-    def test_sort_single_object_with_model(self):
-        self._check_str_roundtrip(('b: 2\n'
-                                   'a: 1\n'
-                                   'c: 3'),
-                                  ('a: 1\n'
-                                   'c: 3\n'
-                                   'b: 2\n'))
-
-    def test_sort_list(self):
-        # Have transform() descend through a list.
-        o = ('- b: 2\n'
-             '  a: 1\n'
-             '- c: 3\n')
-        ref = ('- a: 1\n'
-               '  b: 2\n'
-               '- c: 3\n')
-        self.assertEqual(ref, transform(self._PseudoModel, o))
-
-
 class _ExplicitFieldSelection(TestCase):
+
     def test_absence_of_data_abstract(self):
         with self.assertRaises(AttributeError):
             get_explicit_fields(Document)
@@ -286,24 +287,25 @@ class _ExplicitFieldSelection(TestCase):
             get_explicit_fields(ConcreteDocument)
 
     def test_fair_weather(self):
+
         class SmallExplicitDocument(Document):
 
-            fields_with_markup = (Document.body.field,)
+            fields_with_markup = (Document.body.field, )
 
         # The summary field, which is a MarkupField, should not appear.
-        self.assertEqual((SmallExplicitDocument.body.field,),
+        self.assertEqual((SmallExplicitDocument.body.field, ),
                          SmallExplicitDocument.fields_with_markup)
-        self.assertEqual((SmallExplicitDocument.body.field,),
+        self.assertEqual((SmallExplicitDocument.body.field, ),
                          get_explicit_fields(SmallExplicitDocument))
 
     def test_novel_class(self):
+
         class LargeExplicitDocument(Document):
 
             epigraph = MarkupField()
 
             # Check various ways to refer to fields.
-            fields_with_markup = (Document.body.field,
-                                  epigraph,
+            fields_with_markup = (Document.body.field, epigraph,
                                   Document._meta.get_field('summary'))
 
         self.assertEqual((LargeExplicitDocument.body.field,
@@ -313,19 +315,21 @@ class _ExplicitFieldSelection(TestCase):
 
 
 class _ClassBasedFieldSelection(TestCase):
+
     def test_minimal(self):
         with self.assertRaises(AssertionError):
             classbased_selector({})
 
     def test_mismatch(self):
-        f = classbased_selector((int,))
+        f = classbased_selector((int, ))
         self.assertEqual(f(ConcreteDocument), ())
 
     def test_fair_weather(self):
-        f = classbased_selector((MarkupField,))
-        self.assertEqual(f(ConcreteDocument),
-                         tuple(f for f in ConcreteDocument._meta.fields
-                               if f.name in {'summary', 'ingress', 'body'}))
+        f = classbased_selector((MarkupField, ))
+        self.assertEqual(
+            f(ConcreteDocument),
+            tuple(f for f in ConcreteDocument._meta.fields
+                  if f.name in {'summary', 'ingress', 'body'}))
 
 
 class _CookingSite(TestCase):
@@ -338,7 +342,8 @@ class _CookingSite(TestCase):
         doc = ConcreteDocument.create(**raws)
 
         ref = '**Cove** is a city\nin Union County.\n'
-        self.assertEqual(ref, doc.body,
+        self.assertEqual(ref,
+                         doc.body,
                          msg='Text mutated in document creation.')
 
         list(map_resolver(combo))
@@ -398,9 +403,7 @@ class _Other(TestCase):
 
     def test_markdown_multiline(self):
         s = ('# A', '', '## a', '', '* li', '', 'p', '')
-        ref = ('<h1 id="a">A</h1>', '<h2 id="a_1">a</h2>',
-               '<ul>', '<li>li</li>', '</ul>',
-               '<p>p</p>')
+        ref = ('<h1 id="a">A</h1>', '<h2 id="a_1">a</h2>', '<ul>',
+               '<li>li</li>', '</ul>', '<p>p</p>')
 
-        self.assertEqual('\n'.join(ref),
-                         markdown_on_string('\n'.join(s)))
+        self.assertEqual('\n'.join(ref), markdown_on_string('\n'.join(s)))
